aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorLoïc Hoguin <[email protected]>2012-08-27 13:39:59 +0200
committerLoïc Hoguin <[email protected]>2012-08-27 13:39:59 +0200
commit6d84afd16d214c7e07d9f55e633dbcb0032473bc (patch)
treefcffa83add64d52f45746a9cf1e0f05c138b27ce /src
parentd3dcaf109b225b1384fad5b17dbae9c4888c40ea (diff)
downloadcowboy-6d84afd16d214c7e07d9f55e633dbcb0032473bc.tar.gz
cowboy-6d84afd16d214c7e07d9f55e633dbcb0032473bc.tar.bz2
cowboy-6d84afd16d214c7e07d9f55e633dbcb0032473bc.zip
Rename cowboy_http_rest to cowboy_rest
Diffstat (limited to 'src')
-rw-r--r--src/cowboy_http_static.erl6
-rw-r--r--src/cowboy_rest.erl (renamed from src/cowboy_http_rest.erl)2
2 files changed, 4 insertions, 4 deletions
diff --git a/src/cowboy_http_rest.erl b/src/cowboy_rest.erl
index a9ff934..de12f3f 100644
--- a/src/cowboy_http_rest.erl
+++ b/src/cowboy_rest.erl
@@ -18,7 +18,7 @@
%% can be found in the Webmachine source tree, and on the Webmachine
%% documentation available at http://wiki.basho.com/Webmachine.html
%% at the time of writing.
--module(cowboy_http_rest).
+-module(cowboy_rest).
-export([upgrade/4]).
diff --git a/src/cowboy_http_static.erl b/src/cowboy_http_static.erl
index d8e10a0..ca13532 100644
--- a/src/cowboy_http_static.erl
+++ b/src/cowboy_http_static.erl
@@ -62,7 +62,7 @@
%% `application/octet-stream'. This can be overriden by supplying a list
%% of filename extension to mimetypes pairs in the `mimetypes' option.
%% The filename extension should be a binary string including the leading dot.
%% The mimetypes must be of a type that the `cowboy_http_rest' protocol can
%% handle.
%%
%% The <a href="https://github.com/spawngrid/mimetypes">spawngrid/mimetypes</a>
@@ -176,7 +176,7 @@
%% cowboy_protocol callbacks
-export([init/3]).
-%% cowboy_http_rest callbacks
+%% cowboy_rest callbacks
-export([rest_init/2]).
-export([allowed_methods/2]).
-export([malformed_request/2]).
@@ -208,7 +208,7 @@
%% @private Upgrade from HTTP handler to REST handler.
init({_Transport, http}, _Req, _Opts) ->
- {upgrade, protocol, cowboy_http_rest}.
+ {upgrade, protocol, cowboy_rest}.
%% @private Set up initial state of REST handler.
@@ -62,7 +62,7 @@
%% of filename extension to mimetypes pairs in the `mimetypes' option.
%% The filename extension should be a binary string including the leading dot.
-%% The mimetypes must be of a type that the `cowboy_http_rest' protocol can
+%% The mimetypes must be of a type that the `cowboy_rest' protocol can
%% handle.
%%